agentle.agents.whatsapp.models.whatsapp\_document\_message
==========================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_document_message

   
   .. rubric:: Classes

   .. autosummary::
   
      WhatsAppDocumentMessage
      WhatsAppMediaMessage
      WhatsAppMessageType
   